{% load i18n %}
{% load navactive %}
{% load aa_forum %}

<div class="col-md-3 order-md-last mb-3">
    <div class="card card-default">
        <div class="card-header">
            <div class="card-title mb-0">
                {% translate "Messages" %}
            </div>
        </div>

        <div class="card-body">
            <ul id="aa-forum-messages-sidebar-menu" class="nav flex-column">
                <li class="nav-item aa-forum-messages-sidebar-menu-item">
                    <a class="nav-link {% navactive request 'aa_forum:personal_messages_new_message' %}" href="{% url 'aa_forum:personal_messages_new_message' %}">
                        {% translate "New message" %}
                    </a>
                </li>

                <li class="nav-item aa-forum-messages-sidebar-menu-item">
                    <a class="nav-link {% navactive request 'aa_forum:personal_messages_inbox' %}" href="{% url 'aa_forum:personal_messages_inbox' %}">
                        {% translate "Inbox" %}
                        {% personal_message_unread_count request.user %}
                    </a>
                </li>

                <li class="nav-item aa-forum-messages-sidebar-menu-item">
                    <a class="nav-link {% navactive request 'aa_forum:personal_messages_sent_messages' %}" href="{% url 'aa_forum:personal_messages_sent_messages' %}">
                        {% translate "Sent messages" %}
                    </a>
                </li>
            </ul>
        </div>
    </div>
</div>
