{% load static %}

<link rel="stylesheet" href="{% static 'aa_forum/libs/select2/4.1.0-rc1/css/select2.min.css' %}">
<link rel="stylesheet" href="{% static 'aa_forum/libs/select2-bootstrap-5-theme/1.3.0/select2-bootstrap-5-theme.min.css' %}">
