{% extends "aa_forum/base.html" %}

{% load static %}
{% load i18n %}

{% block page_title %}
    {% translate "Profile" as page_title %}
    {% translate "Forum" as app_title %}

    {{ page_title|title }} » {{ app_title }}
{% endblock %}

{% block aa_forum_body %}
    {% include "aa_forum/partials/profile/form.html" %}
{% endblock %}

{% block extra_css %}
    {% include "aa_forum/bundles/ckeditor5-css.html" %}
    {% include "aa_forum/bundles/aa-forum-css.html" %}
{% endblock %}

{% block extra_javascript %}
    {% include "aa_forum/bundles/ckeditor5-js.html" %}
{% endblock %}
