/*!
 * Select2 v4 Bootstrap 5 theme v1.3.0
*/
.select2-container--bootstrap-5 {
    display: block;
}

select + .select2-container--bootstrap-5 {
    z-index: 1;
}

.select2-container--bootstrap-5 *:focus {
    outline: 0;
}

.select2-container--bootstrap-5 .select2-selection {
    appearance: none;
    background-color: rgb(255 255 255);
    border: 1px solid rgb(206 212 218);
    border-radius: 0.25rem;
    color: rgb(33 37 41);
    font-family: inherit;
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    min-height: calc(1.5em + 0.75rem + 2px);
    padding: 0.375rem 0.75rem;
    transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    width: 100%;
}

@media (prefers-reduced-motion: reduce) {
    .select2-container--bootstrap-5 .select2-selection {
        transition: none;
    }
}

.select2-container--bootstrap-5.select2-container--focus .select2-selection, .select2-container--bootstrap-5.select2-container--open .select2-selection {
    border-color: rgb(134 183 254);
    box-shadow: 0 0 0 0.25rem rgb(13 110 253 / 25%);
}

.select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection {
    border-bottom: 0 solid transparent;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.select2-container--bootstrap-5.select2-container--open.select2-container--above .select2-selection {
    border-top: 0 solid transparent;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.select2-container--bootstrap-5 .select2-search {
    width: 100%;
}

.select2-container--bootstrap-5 .select2-search--inline .select2-search__field {
    vertical-align: top;
}

.select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear,
.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.75rem auto no-repeat;
    height: 0.75rem;
    overflow: hidden;
    padding: 0.25em;
    position: absolute;
    right: 2.25rem;
    text-indent: 100%;
    top: 50%;
    transform: translateY(-50%);
    white-space: nowrap;
    width: 0.75rem;
}

.select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear:hover,
.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.75rem auto no-repeat;
}

.select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear > span,
.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear > span {
    display: none;
}

.select2-container--bootstrap-5 + .select2-container--bootstrap-5 {
    z-index: 1056;
}

.select2-container--bootstrap-5 .select2-dropdown {
    background-color: rgb(255 255 255);
    border-color: rgb(134 183 254);
    border-radius: 0.25rem;
    color: rgb(33 37 41);
    overflow: hidden;
    z-index: 1056;
}

.select2-container--bootstrap-5 .select2-dropdown.select2-dropdown--below {
    border-top: 0 solid transparent;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.select2-container--bootstrap-5 .select2-dropdown.select2-dropdown--above {
    border-bottom: 0 solid transparent;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-search {
    padding: 0.375rem 0.75rem;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field {
    appearance: none;
    background-clip: padding-box;
    background-color: rgb(255 255 255);
    border: 1px solid rgb(206 212 218);
    border-radius: 0.25rem;
    color: rgb(33 37 41);
    display: block;
    font-family: inherit;
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    padding: 0.375rem 0.75rem;
    transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    width: 100%;
}

@media (prefers-reduced-motion: reduce) {
    .select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field {
        transition: none;
    }
}

.select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field:focus {
    border-color: rgb(134 183 254);
    box-shadow: 0 0 0 0.25rem rgb(13 110 253 / 25%);
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options:not(.select2-results__options--nested) {
    max-height: 15rem;
    overflow-y: auto;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option {
    font-size: 1rem;
    font-weight: 400;
    line-height: 1.5;
    padding: 0.375rem 0.75rem;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option.select2-results__message {
    color: rgb(108 117 125);
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option.select2-results__option--highlighted {
    background-color: rgb(233 236 239);
    color: rgb(0 0 0);
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option.select2-results__option--selected, .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[aria-selected="true"]:not(.select2-results__option--highlighted) {
    background-color: rgb(13 110 253);
    color: rgb(255 255 255);
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option.select2-results__option--disabled, .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[aria-disabled="true"] {
    color: rgb(108 117 125);
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] {
    padding: 0;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__group {
    color: rgb(108 117 125);
    font-weight: 500;
    line-height: 1.5;
    padding: 0.375rem;
}

.select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__options--nested .select2-results__option {
    padding: 0.375rem 0.75rem;
}

.select2-container--bootstrap-5 .select2-selection--single {
    background-image: url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3e%3cpath fill='none' stroke='%23343a40' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='M2 5l6 6 6-6'/%3e%3c/svg%3e");
    background-position: right 0.75rem center;
    background-repeat: no-repeat;
    background-size: 16px 12px;
    padding: 0.375rem 2.25rem 0.375rem 0.75rem;
}

.select2-container--bootstrap-5 .select2-selection--single .select2-selection__rendered {
    color: rgb(33 37 41);
    font-weight: 400;
    line-height: 1.5;
    padding: 0;
}

.select2-container--bootstrap-5 .select2-selection--single .select2-selection__rendered .select2-selection__placeholder {
    color: rgb(108 117 125);
    font-weight: 400;
    line-height: 1.5;
}

.select2-container--bootstrap-5 .select2-selection--single .select2-selection__rendered .select2-selection__arrow {
    display: none;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered {
    display: flex;
    flex-flow: row wrap;
    list-style: none;
    margin: 0;
    padding-left: 0;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
    align-items: center;
    border: 1px solid rgb(206 212 218);
    border-radius: 0.25rem;
    color: rgb(33 37 41);
    cursor: auto;
    display: flex;
    flex-direction: row;
    font-size: 1rem;
    margin-bottom: 0.375rem;
    margin-right: 0.375rem;
    padding: 0.35em 0.65em;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.75rem auto no-repeat;
    border: 0;
    height: 0.75rem;
    margin-right: 0.25rem;
    overflow: hidden;
    padding: 0.25em;
    text-indent: 100%;
    white-space: nowrap;
    width: 0.75rem;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.75rem auto no-repeat;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove > span {
    display: none;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-search {
    display: block;
    height: 1.5rem;
    width: 100%;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-search .select2-search__field {
    background-color: transparent;
    font-family: inherit;
    height: 1.5rem;
    line-height: 1.5;
    margin-left: 0;
    margin-top: 0;
    width: 100%;
}

.select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear {
    right: 0.75rem;
}

.select2-container--bootstrap-5.select2-container--disabled .select2-selection, .select2-container--bootstrap-5.select2-container--disabled.select2-container--focus .select2-selection {
    background-color: rgb(233 236 239);
    border-color: rgb(206 212 218);
    box-shadow: none;
    color: rgb(108 117 125);
    cursor: not-allowed;
}

.select2-container--bootstrap-5.select2-container--disabled .select2-selection--multiple .select2-selection__clear, .select2-container--bootstrap-5.select2-container--disabled.select2-container--focus .select2-selection--multiple .select2-selection__clear {
    display: none;
}

.select2-container--bootstrap-5.select2-container--disabled .select2-selection--multiple .select2-selection__choice, .select2-container--bootstrap-5.select2-container--disabled.select2-container--focus .select2-selection--multiple .select2-selection__choice {
    cursor: not-allowed;
}

.select2-container--bootstrap-5.select2-container--disabled .select2-selection--multiple .select2-selection__choice .select2-selection__choice__remove, .select2-container--bootstrap-5.select2-container--disabled.select2-container--focus .select2-selection--multiple .select2-selection__choice .select2-selection__choice__remove {
    display: none;
}

.select2-container--bootstrap-5.select2-container--disabled .select2-selection--multiple .select2-selection__rendered:not(:empty), .select2-container--bootstrap-5.select2-container--disabled.select2-container--focus .select2-selection--multiple .select2-selection__rendered:not(:empty) {
    padding-bottom: 0;
}

.select2-container--bootstrap-5.select2-container--disabled .select2-selection--multiple .select2-selection__rendered:not(:empty) + .select2-search, .select2-container--bootstrap-5.select2-container--disabled.select2-container--focus .select2-selection--multiple .select2-selection__rendered:not(:empty) + .select2-search {
    display: none;
}

.input-group:not(.has-validation) > :not(:last-child, .dropdown-toggle, .dropdown-menu).select2-container--bootstrap-5 .select2-selection {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

.input-group.has-validation > :nth-last-child(n+3):not(.dropdown-toggle, .dropdown-menu).select2-container--bootstrap-5 .select2-selection {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
}

.input-group > .input-group-text ~ .select2-container--bootstrap-5 .select2-selection,
.input-group > .btn ~ .select2-container--bootstrap-5 .select2-selection,
.input-group > .dropdown-menu ~ .select2-container--bootstrap-5 .select2-selection {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}

.input-group .select2-container--bootstrap-5 {
    flex-grow: 1;
}

.input-group .select2-container--bootstrap-5 .select2-selection {
    height: 100%;
}

.is-valid + .select2-container--bootstrap-5 .select2-selection, .was-validated select:valid + .select2-container--bootstrap-5 .select2-selection {
    border-color: rgb(25 135 84);
}

.is-valid + .select2-container--bootstrap-5.select2-container--focus .select2-selection, .is-valid + .select2-container--bootstrap-5.select2-container--open .select2-selection, .was-validated select:valid + .select2-container--bootstrap-5.select2-container--focus .select2-selection, .was-validated select:valid + .select2-container--bootstrap-5.select2-container--open .select2-selection {
    border-color: rgb(25 135 84);
    box-shadow: 0 0 0 0.25rem rgb(25 135 84 / 25%);
}

.is-valid + .select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection, .was-validated select:valid + .select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection {
    border-bottom: 0 solid transparent;
}

.is-valid + .select2-container--bootstrap-5.select2-container--open.select2-container--above .select2-selection, .was-validated select:valid + .select2-container--bootstrap-5.select2-container--open.select2-container--above .select2-selection {
    border-top: 0 solid transparent;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.is-invalid + .select2-container--bootstrap-5 .select2-selection, .was-validated select:invalid + .select2-container--bootstrap-5 .select2-selection {
    border-color: rgb(220 53 69);
}

.is-invalid + .select2-container--bootstrap-5.select2-container--focus .select2-selection, .is-invalid + .select2-container--bootstrap-5.select2-container--open .select2-selection, .was-validated select:invalid + .select2-container--bootstrap-5.select2-container--focus .select2-selection, .was-validated select:invalid + .select2-container--bootstrap-5.select2-container--open .select2-selection {
    border-color: rgb(220 53 69);
    box-shadow: 0 0 0 0.25rem rgb(220 53 69 / 25%);
}

.is-invalid + .select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection, .was-validated select:invalid + .select2-container--bootstrap-5.select2-container--open.select2-container--below .select2-selection {
    border-bottom: 0 solid transparent;
}

.is-invalid + .select2-container--bootstrap-5.select2-container--open.select2-container--above .select2-selection, .was-validated select:invalid + .select2-container--bootstrap-5.select2-container--open.select2-container--above .select2-selection {
    border-top: 0 solid transparent;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.select2-container--bootstrap-5 .select2--small.select2-selection {
    border-radius: 0.2rem;
    font-size: 0.875rem;
    min-height: calc(1.5em + 0.5rem + 2px);
    padding: 0.25rem 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--single .select2-selection__clear,
.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-selection__clear {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
    height: 0.5rem;
    padding: 0.125rem;
    width: 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--single .select2-selection__clear:hover,
.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-selection__clear:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--single .select2-search,
.select2-container--bootstrap-5 .select2--small.select2-selection--single .select2-search .select2-search__field,
.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-search,
.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-search .select2-search__field {
    height: 1.5em;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown {
    border-radius: 0.2rem;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown.select2-dropdown--below {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown.select2-dropdown--above {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown .select2-search .select2-search__field {
    font-size: 0.875rem;
    padding: 0.25rem 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown .select2-results__options .select2-results__option {
    font-size: 0.875rem;
    padding: 0.25rem 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__group {
    padding: 0.25rem;
}

.select2-container--bootstrap-5 .select2--small.select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__options--nested .select2-results__option {
    padding: 0.25rem 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--single {
    padding: 0.25rem 2.25rem 0.25rem 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
    font-size: 0.875rem;
    padding: 0.35em 0.65em;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
    height: 0.5rem;
    padding: 0.125rem;
    width: 0.5rem;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
}

.select2-container--bootstrap-5 .select2--small.select2-selection--multiple .select2-selection__clear {
    right: 0.5rem;
}

.select2-container--bootstrap-5 .select2--large.select2-selection {
    border-radius: 0.3rem;
    font-size: 1.25rem;
    min-height: calc(1.5em + 1rem + 2px);
    padding: 0.5rem 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--single .select2-selection__clear,
.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-selection__clear {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
    height: 1rem;
    padding: 0.5rem;
    width: 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--single .select2-selection__clear:hover,
.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-selection__clear:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--single .select2-search,
.select2-container--bootstrap-5 .select2--large.select2-selection--single .select2-search .select2-search__field,
.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-search,
.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-search .select2-search__field {
    height: 1.5em;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown {
    border-radius: 0.3rem;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown.select2-dropdown--below {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown.select2-dropdown--above {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown .select2-search .select2-search__field {
    font-size: 1.25rem;
    padding: 0.5rem 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown .select2-results__options .select2-results__option {
    font-size: 1.25rem;
    padding: 0.5rem 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__group {
    padding: 0.5rem;
}

.select2-container--bootstrap-5 .select2--large.select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__options--nested .select2-results__option {
    padding: 0.5rem 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--single {
    padding: 0.5rem 2.25rem 0.5rem 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
    font-size: 1.25rem;
    padding: 0.35em 0.65em;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
    height: 1rem;
    padding: 0.5rem;
    width: 1rem;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
}

.select2-container--bootstrap-5 .select2--large.select2-selection--multiple .select2-selection__clear {
    right: 1rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection {
    border-radius: 0.2rem;
    font-size: 0.875rem;
    min-height: calc(1.5em + 0.5rem + 2px);
    padding: 0.25rem 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear,
.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
    height: 0.5rem;
    padding: 0.125rem;
    width: 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear:hover,
.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--single .select2-search,
.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--single .select2-search .select2-search__field,
.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-search,
.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-search .select2-search__field {
    height: 1.5em;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown {
    border-radius: 0.2rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown.select2-dropdown--below {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown.select2-dropdown--above {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field {
    font-size: 0.875rem;
    padding: 0.25rem 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option {
    font-size: 0.875rem;
    padding: 0.25rem 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__group {
    padding: 0.25rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__options--nested .select2-results__option {
    padding: 0.25rem 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--single {
    padding: 0.25rem 2.25rem 0.25rem 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
    font-size: 0.875rem;
    padding: 0.35em 0.65em;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
    height: 0.5rem;
    padding: 0.125rem;
    width: 0.5rem;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/0.5rem auto no-repeat;
}

.form-select-sm ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear {
    right: 0.5rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection {
    border-radius: 0.3rem;
    font-size: 1.25rem;
    min-height: calc(1.5em + 1rem + 2px);
    padding: 0.5rem 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear,
.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
    height: 1rem;
    padding: 0.5rem;
    width: 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--single .select2-selection__clear:hover,
.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--single .select2-search,
.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--single .select2-search .select2-search__field,
.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-search,
.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-search .select2-search__field {
    height: 1.5em;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown {
    border-radius: 0.3rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown.select2-dropdown--below {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown.select2-dropdown--above {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown .select2-search .select2-search__field {
    font-size: 1.25rem;
    padding: 0.5rem 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option {
    font-size: 1.25rem;
    padding: 0.5rem 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__group {
    padding: 0.5rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-dropdown .select2-results__options .select2-results__option[role="group"] .select2-results__options--nested .select2-results__option {
    padding: 0.5rem 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--single {
    padding: 0.5rem 2.25rem 0.5rem 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
    font-size: 1.25rem;
    padding: 0.35em 0.65em;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23676a6d'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
    height: 1rem;
    padding: 0.5rem;
    width: 1rem;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__rendered .select2-selection__choice .select2-selection__choice__remove:hover {
    background: transparent url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='%23000'%3e%3cpath d='M.293.293a1 1 0 011.414 0L8 6.586 14.293.293a1 1 0 111.414 1.414L9.414 8l6.293 6.293a1 1 0 01-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 01-1.414-1.414L6.586 8 .293 1.707a1 1 0 010-1.414z'/%3e%3c/svg%3e") center/1rem auto no-repeat;
}

.form-select-lg ~ .select2-container--bootstrap-5 .select2-selection--multiple .select2-selection__clear {
    right: 1rem;
}
