{% load i18n %}

<div class="modal fade" id="delete-message-{{ message.pk }}" tabindex="-1" role="dialog" aria-labelledby="{% translate 'Delete message' %}" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <div class="modal-title fs-5">
                    {% translate "Delete message" %}
                </div>

                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="{% translate 'Close' %}"></button>
            </div>

            <div class="modal-body">
                <p>{% translate "Are you sure you want to delete this message?" %}</p>
                <p>{% translate "If this message is the original post, then the entire topic will be removed as well." %}</p>

                <div class="aa-callout aa-callout-danger" role="alert">
                    <p>{% translate "This action cannot be undone!" %}</p>
                </div>
            </div>

            <div class="modal-footer">
                <button type="button" class="btn btn-secondary btn-sm" data-bs-dismiss="modal">
                    <i class="fa-regular fa-hand"></i>
                    {% translate "Cancel" %}
                </button>

                <a id="modal-button-confirm" class="btn btn-danger btn-sm" role="button" href="{% url 'aa_forum:forum_message_delete' message.pk %}">
                    <i class="fa-regular fa-trash-can"></i>
                    {% translate "Delete" %}
                </a>
            </div>
        </div>
    </div>
</div>
