{% load i18n %}
{% load django_bootstrap5 %}

<div class="card card-default">
    <div class="card-header">
        <div class="card-title mb-0">
            {% translate "Modify topic" %}
        </div>
    </div>

    <div class="card-body">
        <form id="aa-forum-form-topic-modify" autocomplete="off" action="{% url 'aa_forum:forum_topic_modify' topic.board.category.slug topic.board.slug topic.slug %}" method="post">
            {% csrf_token %}

            {% bootstrap_form form %}

            {% include "aa_forum/partials/form/required-field-hint.html" %}

            <div class="form-group aa-forum-form-group aa-forum-form-modify-topic float-end clearfix">
                <button class="btn btn-primary btn-sm" type="submit">
                    {% translate "Modify" %}
                </button>
            </div>
        </form>
    </div>
</div>
